@@ -1,5 +1,4 @@
 import copy
-from tqdm import tqdm
 import os
 import re
 import subprocess
@@ -152,6 +151,8 @@ def run_nco(command, target, out_file=None, overwrite=False):
 
 def run_cdo(command=None, target=None, out_file=None, overwrite=False, precision=None):
 
+    warned = False
+
     if type(precision) is not str:
         raise ValueError("Precision must be str")
 
@@ -466,6 +467,7 @@ def run_cdo(command=None, target=None, out_file=None, overwrite=False, precision
                             message="CDO warning:"
                             + x.replace("b'Warning:", "").replace("Warning:", "")
                         )
+                        warned = True
 
             if len(missing_years) > 0:
                 warnings.warn(
@@ -473,12 +475,14 @@ def run_cdo(command=None, target=None, out_file=None, overwrite=False, precision
                     "are missing",
                     stacklevel=2,
                 )
+                warned = True
             if len(missing_months) > 0:
                 warnings.warn(
                     message=f'CDO warning: Months {str_flatten(missing_months, ",")} '
                     "are missing",
                     stacklevel=2,
                 )
+                warned = True
     else:
         messages = str(result).split("\\n")
 
@@ -510,6 +514,7 @@ def run_cdo(command=None, target=None, out_file=None, overwrite=False, precision
                         message="CDO warning:"
                         + x.replace("b'Warning:", "").replace("Warning:", "")
                     )
+                    warned = True
 
         if len(missing_years) > 0:
             warnings.warn(
@@ -517,12 +522,14 @@ def run_cdo(command=None, target=None, out_file=None, overwrite=False, precision
                 "are missing!",
                 category=Warning,
             )
+            warned = True
         if len(missing_months) > 0:
             warnings.warn(
                 message=f'CDO warning: Months {str_flatten(missing_months, ",")} '
                 "are missing",
                 category=Warning,
             )
+            warned = True
 
     if os.path.exists(target) is False:
         remove_safe(target)
@@ -531,11 +538,32 @@ def run_cdo(command=None, target=None, out_file=None, overwrite=False, precision
 
     session_info["latest_size"] = os.path.getsize(target)
 
+    x = result.decode("utf-8").lower().split("\n")[0]
+    
+    if "warning" in x and "vertmean" in x:
+        if "layer bounds not available, using constant vertical weights" in x:
+            warnings.warn("Layer bounds not available in netCDF file, using constant vertical weights for vertical mean")
+            warned = True
+
+    if "warning" in x:
+        if "Grid cell bounds not available, using constant grid cell area weights" in x:
+            warnings.warn("CDO warning: Grid cell bounds not available, using constant grid cell area weights for operation")
+            warned = True
+
+    if "warning" in x:
+        if "Computation of grid cell area weights failed, grid cell center and bounds coordinates missing" in x:
+            warnings.warn("CDO warning: Computation of grid cell area weights failed, grid cell center and bounds coordinates missing from netCDF")
+            warned = True
+
+    if not warned:
+        if "arning" in x:
+            warnings.warn(f"CDO warning: {x}")
 
     return target
 
 
-def run_this(os_command, self, output="one", out_file=None):
+def run_this(os_command, self, output="one", out_file=None, suppress = False):
+    from tqdm import tqdm
 
     if len(self) == 0:
         raise ValueError("Failure do to empty dataset!")
@@ -593,10 +621,13 @@ def run_this(os_command, self, output="one", out_file=None):
                 if cores == 1:
                     if progress_bar:
                         if session_info["progress"] == "on":
-                            print("Processing ensemble! In progress:")
+                            if not suppress:
+                                print("Processing ensemble! In progress:")
                         else:
-                            print("Processing large ensemble! In progress")
-                        pbar = tqdm(total=len(file_list))
+                            if not suppress:
+                                print("Processing large ensemble! In progress")
+                        if not suppress:
+                            pbar = tqdm(total=len(file_list), position = 0, leave = True)
 
                 for ff in file_list:
                     ff_command = os_command
@@ -665,20 +696,25 @@ def run_this(os_command, self, output="one", out_file=None):
                         )
                         target_list.append(target)
                         if progress_bar:
-                            pbar.update(1)
+                            if not suppress:
+                                pbar.update(1)
 
                 if cores > 1:
 
                     if progress_bar:
                         if session_info["progress"] == "on":
-                            print("Processing ensemble. In progress:")
+                            if not suppress:
+                                print("Processing ensemble. In progress:")
                         else:
-                            print("Processing a large ensemble. In progress:")
-                        pbar = tqdm(total=len(file_list))
+                            if not suppress:
+                                print("Processing a large ensemble. In progress:")
+                        if not suppress:
+                            pbar = tqdm(total=len(file_list), position = 0, leave = True)
                     for k, v in results.items():
                         target_list.append(v.get())
                         if progress_bar:
-                            pbar.update(1)
+                            if not suppress:
+                                pbar.update(1)
 
                 self.history = copy.deepcopy(new_history)
                 self.current = copy.deepcopy(target_list)
